pub enum Event<'a> {
}Expand description
An event encountered while decoding or encoding CBOR using a streaming basic implementation.
Variants
Unsigned(u64)
An unsigned integer.
Signed(u64)
A signed integer in a slightly odd representation.
The actual value of the integer is -1 minus the provided value.
Some integers that can be CBOR encoded underflow i64.
Use one of the interpret_signed associated functions to resolve this.
ByteString(Cow<'a, [u8]>)
A byte string.
UnknownLengthByteString
The start of a byte string whose length is unknown.
After this event come a series of ByteString events, followed by a Break.
To get the true value of the byte string, concatenate the ByteString events together.
TextString(Cow<'a, str>)
A text string.
UnknownLengthTextString
The start of a text string whose length is unknown.
After this event come a series of TextString events, followed by a Break.
To get the true value of the text string, concatenate the TextString events together.
Array(u64)
The start of an array with a known length.
UnknownLengthArray
The start of an array whose length is unknown.
After this event come a series of events representing the items in the array.
The array ends at the matching Break event.
Map(u64)
The start of a map with a known length.
Note that the actual number of sub-items is twice the length given. The first in each pair is a key, and the second is the value.
UnknownLengthMap
The start of a map with an unknown length.
Tag(u64)
Additional type information for the next CBOR item.
Bool(bool)
A boolean.
Null
The null value.
Undefined
The undefined value.
Float(f64)
A floating-point number.
Break
The end of an unknown-length item.
Implementations
Sourceimpl Event<'_>
impl Event<'_>
Sourcepub fn into_owned(self) -> Event<'static>
pub fn into_owned(self) -> Event<'static>
Convert this Event to an owned value.
Sourcepub fn interpret_signed(val: u64) -> i64
pub fn interpret_signed(val: u64) -> i64
Interpret a Event::Signed value.
Overflow behavior
On overflow, this function will panic if overflow checks are enabled (default in debug mode) and wrap if overflow checks are disabled (default in release mode).
Sourcepub fn interpret_signed_checked(val: u64) -> Option<i64>
pub fn interpret_signed_checked(val: u64) -> Option<i64>
Sourcepub fn interpret_signed_wide(val: u64) -> i128
pub fn interpret_signed_wide(val: u64) -> i128
Interpret a Event::Signed value.
Overflow behavior
This function does not overflow, because it returns an i128.
Sourcepub fn create_signed(val: i64) -> Event<'static>
pub fn create_signed(val: i64) -> Event<'static>
Create a Event::Signed or Event::Unsigned value.
Sourcepub fn create_signed_wide(val: i128) -> Option<Event<'static>>
pub fn create_signed_wide(val: i128) -> Option<Event<'static>>
Create a Event::Signed or Event::Unsigned value.
Because this takes an i128, it can express all the numbers CBOR can encode.
However, some i128s cannot be encoded in basic CBOR integers.
In this case, it will return None.